@@ -10,10 +10,11 @@ from shapash.webapp.smart_app import SmartApp
 from shapash.utils.io import save_pickle
 from shapash.utils.io import load_pickle
 from shapash.utils.transform import inverse_transform, apply_postprocessing
-from shapash.utils.transform import adapt_contributions
+from shapash.utils.transform import adapt_contributions, get_features_transform_mapping
 from shapash.utils.utils import get_host_name
 from shapash.utils.threading import CustomThread
 from shapash.utils.shap_backend import shap_contributions, check_explainer, get_shap_interaction_values
+from shapash.utils.acv_backend import active_shapley_values, compute_features_import_acv
 from shapash.utils.check import check_model, check_label_dict, check_ypred, check_contribution_object,\
     check_postprocessing, check_features_name
 from shapash.manipulation.select_lines import keep_right_contributions
@@ -118,7 +119,7 @@ class SmartExplainer:
                 label_dict must be a dict
                 """
             )
-        self.features_dict = features_dict
+        self.features_dict = copy.deepcopy(features_dict)
         self.label_dict = label_dict
         self.plot = SmartPlotter(self)
         if title_story is not None:
@@ -129,7 +130,7 @@ class SmartExplainer:
 
     def compile(self, x, model, explainer=None, contributions=None, y_pred=None,
                 preprocessing=None, postprocessing=None, title_story: str = None,
-                features_groups=None):
+                features_groups=None, backend='shap', **kwargs):
         """
         The compile method is the first step to understand model and prediction. It performs the sorting
         of contributions, the reverse preprocessing steps and performs all the calculations necessary for
@@ -197,6 +198,9 @@ class SmartExplainer:
             ‘feature_group_1’ : ['feature3', 'feature7', 'feature24'],
             ‘feature_group_2’ : ['feature1', 'feature12'],
             }
+        backend : str (default: 'shap')
+            Select which computation method to use in order to compute contributions
+            and feature importance. Possible values are 'shap' or 'acv'. Default is 'shap'.
 
         Example
         --------
@@ -213,8 +217,25 @@ class SmartExplainer:
             self.inv_label_dict = {v: k for k, v in self.label_dict.items()}
         if explainer is not None and contributions is not None:
             raise ValueError("You have to specify just one of these arguments: explainer, contributions")
+
+        # Computing contributions using right backend
         if contributions is None:
-            contributions, explainer = shap_contributions(model, self.x_init, self.check_explainer(explainer))
+            if backend.lower() == 'shap':
+                contributions, explainer = shap_contributions(model, self.x_init, self.check_explainer(explainer))
+            elif backend.lower() == 'acv':
+                self.backend = 'acv'
+                if features_groups is not None:
+                    raise ValueError('ACV does not support groups of features for now.')
+                if self._case == 'classification':
+                    contributions, explainer, self.sdp_index, self.sdp = active_shapley_values(
+                        model=model, x_init=self.x_init, x_pred=self.x_pred, explainer=explainer,
+                        preprocessing=preprocessing, **kwargs
+                    )
+                else:
+                    raise NotImplementedError('ACV does not support regression case yet.')
+            else:
+                raise ValueError(f'Unknown backend : {backend}. Possible values are "shap" or "acv".')
+
         adapt_contrib = self.adapt_contributions(contributions)
         self.state = self.choose_state(adapt_contrib)
         self.contributions = self.apply_preprocessing(self.validate_contributions(adapt_contrib), preprocessing)
@@ -268,6 +289,7 @@ class SmartExplainer:
                 self.x_pred_groups
             )
         )
+        self.columns_dict_groups = {i: col for i, col in enumerate(self.x_pred_groups.columns)}
 
     def add(self, y_pred=None, label_dict=None, features_dict=None, title_story: str = None):
         """
@@ -421,7 +443,8 @@ class SmartExplainer:
         if preprocessing:
             return self.state.inverse_transform_contributions(
                 contributions,
-                preprocessing
+                preprocessing,
+                agg_columns='first' if hasattr(self, 'backend') and self.backend == 'acv' else 'sum'
             )
         else:
             return contributions
@@ -628,7 +651,7 @@ class SmartExplainer:
 
         return label_num, label_code, label_value
 
-    def check_features_name(self, features):
+    def check_features_name(self, features, use_groups=False):
         """
         Convert a list of feature names (string) or features ids into features ids.
         Features names can be part of columns_dict or features_dict.
@@ -637,13 +660,16 @@ class SmartExplainer:
         ----------
         features : List
             List of ints (columns ids) or of strings (business names)
+        use_groups : bool
+            Whether or not features parameter includes groups of features
 
         Returns
         -------
         list of ints
             Columns ids compatible with var_dict
         """
-        return check_features_name(self.columns_dict, self.features_dict, features)
+        columns_dict = self.columns_dict if use_groups is False else self.columns_dict_groups
+        return check_features_name(columns_dict, self.features_dict, features)
 
     def check_features_desc(self):
         """
@@ -720,7 +746,7 @@ class SmartExplainer:
             mask.append(
                 self.state.hide_contributions(
                     data['var_dict'],
-                    features_list=self.check_features_name(features_to_hide)
+                    features_list=self.check_features_name(features_to_hide, use_groups=display_groups)
                 )
             )
         if threshold:
@@ -945,18 +971,35 @@ class SmartExplainer:
             Each Serie: feature importance, One row by feature,
             index of the serie = contributions.columns
         """
-        if self.features_groups is not None and self.features_imp_groups is None:
-            self.features_imp_groups = self.state.compute_features_import(self.contributions_groups)
-        if self.features_imp is None or force:
-            self.features_imp = self.state.compute_features_import(self.contributions)
+        if hasattr(self, 'backend') and self.backend == 'acv':
+            features_mapping = get_features_transform_mapping(self.x_pred, self.x_init, self.preprocessing)
+            features_imp = compute_features_import_acv(
+                self.sdp_index, self.sdp, self.x_init.columns, features_mapping
+            )
+            if isinstance(self.contributions, list):
+                self.features_imp = [features_imp for _ in range(len(self.contributions))]
+            else:
+                self.features_imp = features_imp
+        else:
+            if self.features_groups is not None and self.features_imp_groups is None:
+                self.features_imp_groups = self.state.compute_features_import(self.contributions_groups)
+            if self.features_imp is None or force:
+                self.features_imp = self.state.compute_features_import(self.contributions)
 
-    def init_app(self):
+    def init_app(self, settings: dict = None):
         """
         Simple init of SmartApp in case of host smartapp by another way
+        
+        Parameters
+        ----------
+        settings : dict (default: None)
+            A dict describing the default webapp settings values to be used
+            Possible settings (dict keys) are 'rows', 'points', 'violin', 'features'
+            Values should be positive ints
         """
-        self.smartapp = SmartApp(self)
+        self.smartapp = SmartApp(self, settings)
 
-    def run_app(self, port: int = None, host: str = None, title_story: str = None) -> CustomThread:
+    def run_app(self, port: int = None, host: str = None, title_story: str = None, settings: dict = None) -> CustomThread:
         """
         run_app method launches the interpretability web app associated with the shapash object.
         run_app method can be used directly in a Jupyter notebook
@@ -976,6 +1019,10 @@ class SmartExplainer:
         title_story: str (default: None)
             The default title is empty. You can specify a custom title
             for your webapp (can be reused in other methods like in a report, ...)
+        settings : dict (default: None)
+            A dict describing the default webapp settings values to be used
+            Possible settings (dict keys) are 'rows', 'points', 'violin', 'features'
+            Values should be positive ints
 
         Returns
         -------
@@ -993,7 +1040,7 @@ class SmartExplainer:
         if self.y_pred is None:
             self.predict()
         if hasattr(self, '_case'):
-            self.smartapp = SmartApp(self)
+            self.smartapp = SmartApp(self, settings)
             if host is None:
                 host = "0.0.0.0"
             if port is None:
