@@ -1,7 +1,7 @@
 """
 load_smartpredictor module
 """
-from shapash.explainer.smart_explainer import SmartPredictor
+from shapash.explainer.smart_predictor import SmartPredictor
 from shapash.utils.io import load_pickle
 
 def load_smartpredictor(path):
